@@ -6,8 +6,6 @@ use core::ops;
 mod heap_alloc;
 
 pub use heap_alloc::HeapAllocator;
-#[cfg(not(feature="no-stdlib"))]
-use alloc_no_stdlib::HeapPrealloc;
 mod tests;
 extern {
   fn calloc(n_elem : usize, el_size : usize) -> *mut u8;
@@ -27,36 +25,6 @@ use alloc_no_stdlib::StackAllocator;
 use alloc_no_stdlib::bzero;
 declare_stack_allocator_struct!(CallocAllocatedFreelist4, 4, calloc);
 declare_stack_allocator_struct!(StackAllocatedFreelist16, 16, stack);
-#[cfg(feature="no-stdlib")]
-fn show_heap_prealloc() {
-
-}
-#[cfg(not(feature="no-stdlib"))]
-fn show_heap_prealloc() {
-  let mut zero_global_buffer = define_allocator_memory_pool!(4, u8, [0; 1024 * 1024 * 20], heap);
-
-  let mut boxallocator = HeapPrealloc::<u8>::new_allocator(1024 * 1024, &mut zero_global_buffer, bzero);
-
-  {
-    let mut x = boxallocator.alloc_cell(9999);
-    x.slice_mut()[0] = 3;
-    let mut y = boxallocator.alloc_cell(4);
-    y[0] = 5;
-    boxallocator.free_cell(y);
-
-    let mut three = boxallocator.alloc_cell(3);
-    three[0] = 6;
-    boxallocator.free_cell(three);
-
-    let mut z = boxallocator.alloc_cell(4);
-    z.slice_mut()[1] = 8;
-    let mut reget_three = boxallocator.alloc_cell(4);
-    reget_three.slice_mut()[1] = 9;
-    //y.mem[0] = 6; // <-- this is an error (use after free)
-    println!("x[0] = {:?} z[0] = {:?}  z[1] = {:?} r3[0] = {:?} r3[1] = {:?}", x.mem[0], z.mem[0], z.mem[1], reget_three[0], reget_three.slice()[1]);
-    let mut _z = boxallocator.alloc_cell(1);
-  }
-}
 
 fn main() {
   let mut global_buffer = unsafe {define_allocator_memory_pool!(4, u8, [0; 1024 * 1024 * 200], calloc)};
@@ -122,5 +90,4 @@ fn main() {
       println!("x[0] {:?} x[9] {:?} y[0] {:?} z[0] {:?}",
                x[0], x[9], -999, z[0]);
   }
-  show_heap_prealloc();
 }
